import numpy as np

def create_colormap_from_with_fixed_hue(name, color, N=10, use_saturation=True):
    """Create a linear segmented colormap with fixed hue set by rgb input color.
    Set saturation and value from builtin colormap.

    Parameters:
    `name`: string containing name of the colormap
    `color`: rgb format color that determines the hue.
    `N`: number of colors used in the palette from which the colormap is built.
    """
    from matplotlib.colors import rgb_to_hsv, hsv_to_rgb, hex2color, LinearSegmentedColormap
    import seaborn as sns

    Blues_rgb = sns.color_palette("Blues", 10)
    Blues_hsv = np.array(list(map(rgb_to_hsv, Blues_rgb)))
    h_array, s_array, v_array = Blues_hsv.T
    # Hue is constant, saturation rises monotonically from 0 to 1
    # Value decreases monotonically from 1 to 0.5 with color index in the palette.
    # Value is interpreted as mixture with grayscale: from 0 (black) to 1 (white).

    # To have greater distinction in our palette we also vary the saturation.
    # We need to pick this up as a weighting factor from the input color.

    # Setup array filled with the hue of the current color
    color_hsv     = rgb_to_hsv(hex2color(color))
    h_array_fixed = np.ones_like(h_array) * color_hsv[0]
    # Create array of rgb values with fixed hue and varying saturation and value
    if use_saturation:
        s_array *= color_hsv[1]
    color_array = np.array(
        list(
            map(
                hsv_to_rgb, np.vstack([h_array_fixed, s_array*color_hsv[1], v_array]).T
            )
        )
    )
    # Now create the colormap
    return LinearSegmentedColormap.from_list(name, color_array)
